#
# spec file for package perl-XML-Twig
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name XML-Twig
Name:           perl-XML-Twig
Version:        3.530.0
Release:        2.1
# 3.53 -> normalize -> 3.530.0
%define cpan_version 3.53
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        XML, The Perl Way
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MI/MIROD/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
Patch0:         perl-XML-Twig-CVE-2016-9180.patch
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(XML::Parser) >= 2.23
Requires:       perl(XML::Parser) >= 2.23
Provides:       perl(XML::Twig) = %{version}
Provides:       perl(XML::Twig::Elt)
Provides:       perl(XML::Twig::Entity)
Provides:       perl(XML::Twig::Entity_list)
Provides:       perl(XML::Twig::Notation)
Provides:       perl(XML::Twig::Notation_list)
Provides:       perl(XML::Twig::XPath)
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  expat
BuildRequires:  perl-HTML-Tidy
BuildRequires:  perl-IO-CaptureOutput
BuildRequires:  perl-Test-Exception
BuildRequires:  perl-Test-Pod
BuildRequires:  perl-Text-Iconv
BuildRequires:  perl-Text-Wrapper
BuildRequires:  perl-Tie-IxHash
BuildRequires:  perl-Unicode-Map8
BuildRequires:  perl-XML-Filter-BufferText
BuildRequires:  perl-XML-Handler-YAWriter
BuildRequires:  perl-XML-Parser
BuildRequires:  perl-XML-SAX-Writer
BuildRequires:  perl-XML-Simple
BuildRequires:  perl-XML-XPath
BuildRequires:  perl-XML-XPathEngine
Requires:       expat
Requires:       perl-XML-Parser
Requires:       perl(Encode)
# MANUAL END

%description
This module provides a way to process XML documents. It is build on top of
'XML::Parser'.

The module offers a tree interface to the document, while allowing you to
output the parts of it that have been completely processed.

It allows minimal resource (CPU and memory) usage by building the tree only
for the parts of the documents that need actual processing, through the use
of the 'twig_roots ' and 'twig_print_outside_roots ' options. The 'finish '
and 'finish_print ' methods also help to increase performances.

XML::Twig tries to make simple things easy so it tries its best to takes
care of a lot of the (usually) annoying (but sometimes necessary) features
that come with XML and XML::Parser.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes check_optional_modules filter_for_5.005 README speedup Twig_pm.slow

%changelog
* Thu Jan 16 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Also provide perl(XML::Twig::XPath), as provided by the file
  /usr/lib/perl5/vendor_perl/*/XML/Twig/XPath.pm.
* Fri Jan 10 2025 Tina Müller <tina.mueller@suse.com>
- Update perl-XML-Twig-CVE-2016-9180.patch
* Sat Dec 14 2024 Tina Müller <timueller+perl@suse.de>
- updated to 3.530.0 (3.53)
  see /usr/share/doc/packages/perl-XML-Twig/Changes
  3.53 - 2024-12-10 - minor maintenance release
  - fixed warning from recent perl version
    See RT#155759 https://rt.cpan.org/Public/Bug/Display.html?id=155759
  - fixed bug with namespaced elements in navigation
  - added multiclass selectors in navigation and handler triggers
    (css style, eg elt.class1.class2)
  - fixed bug with dots in element names confusing navigation
    conditions in some cases
  - fixed output when a CDATA section includes a CDATA end marker
    spotted by Djibril
* Mon Mar  4 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Jul 13 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Security fix [bsc#1008644, CVE-2016-9180]
  * Setting expand_external_ents to 0 or -1 currently doesn't work
    as expected; To completely turn off expanding external entities
    use no_xxe.
  * Update documentation for XML::Twig to mention problems with
    expand_external_ents and add information about new no_xxe argument
  * Add test CVE-2016-9180.t
  * Add test build-requirements:
    perl-Test-Exception, perl-Text-Iconv, perl-Unicode-Map8
- Add perl-XML-Twig-CVE-2016-9180.patch
* Thu Nov 24 2016 coolo@suse.com
- updated to 3.52
  see /usr/share/doc/packages/perl-XML-Twig/Changes
  3.52 - 2016-11-23  - minor maintenance release
  - fixed: the previous fix was buggy...
  3.51 - 2016-11-23  - minor maintenance release
  - fixed: failing tests when XML::XPathEngine and XML::XPath not available
* Wed Nov 23 2016 coolo@suse.com
- updated to 3.50
  see /usr/share/doc/packages/perl-XML-Twig/Changes
* Tue Apr 14 2015 coolo@suse.com
- updated to 3.49
  see /usr/share/doc/packages/perl-XML-Twig/Changes
  3.49 - 2015-03-24
  - added: the DTD_base option to XML::Twig new, that forces XML::Twig to look
    for the DTD in a given directory
    thanks to Arun lakhana for the idea
  - fixed: XML::Parser 2.43 caused a failure in the tests due to a change in
    its behaviour when die-ing.
  - fixed: prevent PAUSE from trying to index packages that are only used
    for monkey patching (to re-use XML::XPath as the XPath engine for
    XML::Twig::XPath).  Will also prevent UNAUTHORIZED flag on metacpan.
    patch sent by Graham Knop
  - fixed: RT #96009
    keep_atts_order => 0 behaviour. Spotted by Dolmen
    https://rt.cpan.org/Public/Bug/Display.html?id=96009
  - fixed bug RT #97461
    wrong error message was returned calling parse on an invalid filehandle
    Thanks to Slaven Rezic for the bug report and test case
    https://rt.cpan.org/Public/Bug/Display.html?id=97461
  - fixed: RT #98801
    COMPATIBILITY WARNING
    inconsistency between simplify and XML::Simple for empty elements (including
    elements with start and end tags but no contents)
    the XML::Simple behaviour is to map them to an empty hash, not an
    empty/undef scalar (depending of whether the element is a PCDATA or not)
    as was the case in previous versions of the module.
    This has the potential to break some existing code, but simplify should be
    strictly the same as XML::Simple's XMLin
    Thanks to Vangelis Katsikaros for the bug report and test case
    https://rt.cpan.org/Public/Bug/Display.html?id=98801
* Mon Sep 15 2014 coolo@suse.com
- updated to 3.48
  - fixed: missing entities when parsing HTML
  RT #93604 https://rt.cpan.org/Public/Bug/Display.html?id=93604
  - fixed: tests failed when using a version of HTML::TreeBuilder with a non-numeric version
  - fixed in twig_handlers, '=' in regexps on attributes are turned into 'eq'
  RT #94295 https://rt.cpan.org/Public/Bug/Display.html?id=94295
  - fixed: test failed on Windows
* Sat Mar 15 2014 coolo@suse.com
- updated to 3.46
  - fixed: link to idented_a format description
  RT #85400 https://rt.cpan.org/Public/Bug/Display.html?id=85400
  fixed by Martin McGrath
  - fixed: code that gave a warning in 5.19.9
  - fixed: RT #86651 https://rt.cpan.org/Ticket/Display.html?id=86773
  xml_pp, quote not escaped in attribute values
  - fixed various typos in docs RT#87660
  thanks to David Steinbrunner
  - fixed: RT #86773 https://rt.cpan.org/Ticket/Display.html?id=86773
  CDATA sections in HTML were not properly escaped when using the
  (default) HTML::TreeBuilder conversion
  spotted by Marco Pessotto
  - fixed: RT #85933 https://rt.cpan.org/Ticket/Display.html?id=85933
  quotes in attributes were not properly escaped
  dpotted by Arun Lakhana
  - added: docs for tools and safe_print_to_file
  - added: support for XPath variables
  thanks to Nathan Glenn for the initial implementation
  - updated: Changes to conform to CPAN::Changes + test
* Tue Jun  4 2013 coolo@suse.com
- updated to 3.44
  [#] minor maintenance release
  added: XML::Twig::Elt new method now acccepts literal content, eg
    my $e= XML::Twig::Elt->new( '<div><p>foo</p><p>bar</p></div>');
  fixed: merge had some problems dealing with embedded comments
  improved: more tests
  improved: docs for parse, see RT #78877
    https://rt.cpan.org/Ticket/Display.html?id=78877
  fixed: xml_pp -i now preserves the permissions of the
    original file, see RT #81165
    https://rt.cpan.org/Ticket/Display.html?id=81165
    reported by Alberto Simoes
  fixed: RT #80503 Newlines in attribute values
    https://rt.cpan.org/Ticket/Display.html?id=80503
    reported (and explained) by Ambrus Zsban: \r, \n
    and \n explicitely set in attribute values should
    be escaped (with &#x<nb>;) when output
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Nov 27 2012 dap.darkness@gmail.com
- update to 3.42
  * fixed: bug, elements created with XML::Twig::Elt
  * added: some tests
- passed the spec file through spec cleaner
- strip %%clean section (not needed on BS)
* Fri Sep 23 2011 vcizek@suse.com
- update to 3.39
  - no upstream changelog,
    see https://github.com/mirod/xmltwig/commits/master
    for individual commits
- licence correction
* Sun Feb 27 2011 pascal.bleser@opensuse.org
- update to 3.38:
  * fixed: RT#65865: _ should be allowed at the start on an XML name
  * removed: making att and class lvalues created problems: in certain context
    they made regular calls to the method create empty        attributes. I
    could find no satisfactory fix,they were either incompletes, or to complex
    for often used methods. So att and class are back to being regular, non
    l-value methods.  latt and lclass are the l-value versions.
  * added: documented the -html option for xml_grep, that allows processing
    HTML input
  * added: the -Tidy option to xml_grep, that uses HTML::Tidy to convert HTML
    to XML
* Thu Dec 16 2010 anicka@suse.cz
- update to 3.37
  * fixed: more tests fixed for HTML::TreeBuilder, hopefully
  will pass now
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Thu Oct  7 2010 anicka@suse.cz
- update to 3.36
  * bugfixes
* Fri Jul 16 2010 anicka@suse.cz
- update to 3.35
  * bugfixes
* Mon Jan 25 2010 anicka@suse.cz
- update to 3.34
  * bugfixes, test suite fixes
* Wed Nov 21 2007 anicka@suse.cz
- update to 3.32
  * bugfixes, test fixes
  * fixed a couple of bugs in namespace handling
  * added the XML::Twig::Elt fields method which returns a list of
  fields
  * added the normalize method in XML::Twig and XML::Twig::Elt
  * added the indented_a / cvs format for pretty_print,
  * Added the XML::Twig method finish_now that terminates parsing
  immediately, without checking the rest of the XML.
  * HTML parsing improved: XML::Twig now tries to find the proper
  encoding for the document
* Thu Oct 18 2007 anicka@suse.cz
- package created (version 3.29) [#297511]
